@@ -13,18 +13,18 @@ import (
 	"testing"
 	"time"
 
+	"github.com/openshift/cluster-image-registry-operator/defaults"
+	"github.com/openshift/cluster-image-registry-operator/test/framework"
+
+	configapiv1 "github.com/openshift/api/config/v1"
+	imageregistryapiv1 "github.com/openshift/api/imageregistry/v1"
+	operatorapiv1 "github.com/openshift/api/operator/v1"
+	appsapi "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/apimachinery/pkg/util/wait"
-
-	configapiv1 "github.com/openshift/api/config/v1"
-	operatorapiv1 "github.com/openshift/api/operator/v1"
-
-	imageregistryapiv1 "github.com/openshift/api/imageregistry/v1"
-	"github.com/openshift/cluster-image-registry-operator/defaults"
-	"github.com/openshift/cluster-image-registry-operator/test/framework"
 )
 
 func TestPodResourceConfiguration(t *testing.T) {
@@ -90,6 +90,61 @@ func TestPodResourceConfiguration(t *testing.T) {
 	}
 }
 
+func TestRolloutStrategyConfiguration(t *testing.T) {
+	client := framework.MustNewClientset(t, nil)
+
+	defer framework.MustRemoveImageRegistry(t, client)
+
+	cr := &imageregistryapiv1.Config{
+		ObjectMeta: metav1.ObjectMeta{
+			Name: defaults.ImageRegistryResourceName,
+		},
+		Spec: imageregistryapiv1.ImageRegistrySpec{
+			ManagementState: operatorapiv1.Managed,
+			Storage: imageregistryapiv1.ImageRegistryConfigStorage{
+				EmptyDir: &imageregistryapiv1.ImageRegistryConfigStorageEmptyDir{},
+			},
+			Replicas: 1,
+			Resources: &corev1.ResourceRequirements{
+				Limits: corev1.ResourceList{
+					corev1.ResourceMemory: resource.MustParse("512Mi"),
+				},
+			},
+			RolloutStrategy: string(appsapi.RecreateDeploymentStrategyType),
+			NodeSelector: map[string]string{
+				"node-role.kubernetes.io/master": "",
+			},
+			Tolerations: []corev1.Toleration{
+				{
+					Key:      "node-role.kubernetes.io/master",
+					Operator: "Exists",
+					Effect:   "NoSchedule",
+				},
+			},
+		},
+	}
+	framework.MustDeployImageRegistry(t, client, cr)
+	framework.MustEnsureImageRegistryIsAvailable(t, client)
+	framework.MustEnsureClusterOperatorStatusIsNormal(t, client)
+
+	deployments, err := client.Deployments(defaults.ImageRegistryOperatorNamespace).List(metav1.ListOptions{})
+	if err != nil {
+		t.Fatal(err)
+	}
+	if len(deployments.Items) == 0 {
+		t.Errorf("no deployments found in registry namespace")
+	}
+
+	registryDeployment, err := client.Deployments(defaults.ImageRegistryOperatorNamespace).Get(defaults.ImageRegistryName, metav1.GetOptions{})
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	if registryDeployment.Spec.Strategy.Type != appsapi.RecreateDeploymentStrategyType {
+		t.Errorf("expected %v deployment strategy", appsapi.RecreateDeploymentStrategyType)
+	}
+}
+
 func TestPodTolerationsConfiguration(t *testing.T) {
 	client := framework.MustNewClientset(t, nil)
 
@@ -179,7 +234,7 @@ func TestOperatorProxyConfiguration(t *testing.T) {
 	client := framework.MustNewClientset(t, nil)
 
 	defer framework.MustRemoveImageRegistry(t, client)
-	defer framework.ResetClusterProxyConfig(client)
+	defer framework.MustResetClusterProxyConfig(t, client)
 
 	framework.MustDeployImageRegistry(t, client, nil)
 	framework.MustEnsureImageRegistryIsAvailable(t, client)
@@ -251,8 +306,8 @@ func TestOperandProxyConfiguration(t *testing.T) {
 	client := framework.MustNewClientset(t, nil)
 
 	defer framework.MustRemoveImageRegistry(t, client)
-	defer framework.ResetClusterProxyConfig(client)
-	defer framework.ResetResourceProxyConfig(client)
+	defer framework.MustResetClusterProxyConfig(t, client)
+	defer framework.MustResetResourceProxyConfig(t, client)
 
 	resourceProxyConfig := imageregistryapiv1.ImageRegistryConfigProxy{
 		NoProxy: "resourcenoproxy.example.com",
@@ -439,18 +494,25 @@ func TestSecureRouteConfiguration(t *testing.T) {
 	framework.MustEnsureClusterOperatorStatusIsNormal(t, client)
 	framework.EnsureExternalRegistryHostnamesAreSet(t, client, []string{hostname})
 
-	route, err := client.Routes(defaults.ImageRegistryOperatorNamespace).Get(routeName, metav1.GetOptions{})
+	err = wait.Poll(5*time.Second, 1*time.Minute, func() (done bool, err error) {
+		route, err := client.Routes(defaults.ImageRegistryOperatorNamespace).Get(routeName, metav1.GetOptions{})
+		if err != nil {
+			t.Logf("unable to get route: %s", err)
+			return false, nil
+		}
+		if route.Spec.TLS == nil {
+			t.Fatal("route.Spec.TLS is nil, want a configuration")
+		}
+		if route.Spec.TLS.Certificate != string(cert) {
+			t.Errorf("route tls certificate: got %q, want %q", route.Spec.TLS.Certificate, string(cert))
+		}
+		if route.Spec.TLS.Key != string(key) {
+			t.Errorf("route tls key: got %q, want %q", route.Spec.TLS.Key, string(key))
+		}
+		return true, nil
+	})
 	if err != nil {
-		t.Fatalf("unable to get route: %s", err)
-	}
-	if route.Spec.TLS == nil {
-		t.Fatal("route.Spec.TLS is nil, want a configuration")
-	}
-	if route.Spec.TLS.Certificate != string(cert) {
-		t.Errorf("route tls certificate: got %q, want %q", route.Spec.TLS.Certificate, string(cert))
-	}
-	if route.Spec.TLS.Key != string(key) {
-		t.Errorf("route tls key: got %q, want %q", route.Spec.TLS.Key, string(key))
+		t.Fatalf("failed to observe the route: %s", err)
 	}
 }
 
